/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { QueryFormData } from '@superset-ui/core';
/**
 * The buildQuery function is used to create an instance of QueryContext that's
 * sent to the chart data endpoint. In addition to containing information of which
 * datasource to use, it specifies the type (e.g. full payload, samples, query) and
 * format (e.g. CSV or JSON) of the result and whether or not to force refresh the data from
 * the datasource as opposed to using a cached copy of the data, if available.
 *
 * More importantly though, QueryContext contains a property `queries`, which is an array of
 * QueryObjects specifying individual data requests to be made. A QueryObject specifies which
 * columns, metrics and filters, among others, to use during the query. Usually it will be enough
 * to specify just one query based on the baseQueryObject, but for some more advanced use cases
 * it is possible to define post processing operations in the QueryObject, or multiple queries
 * if a viz needs multiple different result sets.
 * * Функция buildQuery используется для создания экземпляра QueryContext, который
* отправляется в конечную точку данных диаграммы. В дополнение к содержащей информацию, о которой
* используемый источник данных указывает тип (например, полная полезная нагрузка, образцы, запрос) и
* формат (например, CSV или JSON) результата, а также следует ли принудительно обновлять данные из
* источник данных в отличие от использования кэшированной копии данных, если таковая имеется.
*
* Что еще более важно, QueryContext содержит свойство `queries`, которое представляет собой массив
* Объекты запроса, определяющие индивидуальные запросы данных, которые должны быть сделаны. Объект запроса указывает, какой
* столбцы, метрики и фильтры, среди прочего, для использования во время запроса. Обычно этого будет достаточно
* чтобы указать только один запрос на основе baseQueryObject, но для некоторых более сложных вариантов использования
* можно определить операции постобработки в QueryObject или несколько запросов
* если для viz требуется несколько разных наборов результатов.
 */
export default function buildQuery(formData: QueryFormData): import("@superset-ui/core").QueryContext;
//# sourceMappingURL=buildQuery.d.ts.map